"
 COPYRIGHT (c) 1994 by AEG Industry Automation
 COPYRIGHT (c) 1994 by Claus Gittinger
	      All Rights Reserved

 This software is furnished under a license and may be used
 only in accordance with the terms of that license and with the
 inclusion of the above copyright notice.   This software may not
 be provided or otherwise made available to, or used by, any
 other person.  No title to or ownership of the software is
 hereby transferred.
"

Model subclass:#SelectionInHierarchy
	instanceVariableNames:'root list selection'
	classVariableNames:''
	poolDictionaries:''
	category:'Interface-Support-Models'
!

!SelectionInHierarchy  class methodsFor:'documentation'!

copyright 
"
 COPYRIGHT (c) 1994 by AEG Industry Automation
 COPYRIGHT (c) 1994 by Claus Gittinger
	      All Rights Reserved

 This software is furnished under a license and may be used
 only in accordance with the terms of that license and with the
 inclusion of the above copyright notice.   This software may not
 be provided or otherwise made available to, or used by, any
 other person.  No title to or ownership of the software is
 hereby transferred.
"
!

documentation
"
    model for a selection in a hierarchical list.
    See examples in SelectionInHierarchyView.

    [Author:]
        W. Olberding AEG Factory Automation

    [See also:]
        SelectionInHierarchyView
"
! !

!SelectionInHierarchy methodsFor:'accessing'!

add: aHierarchyNode  below: existingHierarchyNode
	"Add a new HierarchyNode to the tree."


	 existingHierarchyNode addChild: aHierarchyNode. 
	 self setNewList.

	"Modified: 10.10.94 / 16:13:36 / W.Olberding"!

add: aHierarchyNode  belowIndex: anIndex
	"Add a new HierarchyNode to the tree below the node
	which is found in the list at anIndex."

       | existingHierarchyNode |
	 existingHierarchyNode := list at: anIndex  ifAbsent: [^nil]. 
	 self add: aHierarchyNode  below: existingHierarchyNode

	"Modified: 10.10.94 / 16:13:36 / W.Olberding"!

getHierarchyNodeForContents: something

     "return the hierarchyNode wich contents is something"

     |allNodes|

     allNodes:= root allChildren.
     allNodes do: [:each|
	  (each contents = something) ifTrue:[^each].
     ].
     ^nil

	"Modified: 10.10.94 / 16:13:36 / W.Olberding"!

list
	"Answer a collection of nodes representing the
	list of currently viewed objects."

	^list

	"Modified: 10.10.94 / 16:13:36 / W.Olberding"!

remove: aHierarchyNode
	"Remove aHierarchyNode and all its children. "

	 aHierarchyNode removeYourself.   
	 self setNewList.
	^aHierarchyNode

	"Modified: 10.10.94 / 16:13:36 / W.Olberding"!

removeBelow: existingHierarchyNode
	"Remove all children below an existingHierarchyNode ."


	 existingHierarchyNode removeAllChildren. 
	 self setNewList.

	"Modified: 10.10.94 / 16:13:36 / W.Olberding"!

removeBelowIndex: anIndex
	"Remove all the children of aHierarchyNode 
	which is found in the list at anIndex."

       | existingHierarchyNode |
	 existingHierarchyNode := list at: anIndex ifAbsent: [^nil]. 
	^self removeBelow: existingHierarchyNode.

	"Modified: 10.10.94 / 16:13:37 / W.Olberding"!

removeIndex: anIndex
	"Remove the HierarchyNode and all its children
	which is found in the list at anIndex."

       | existingHierarchyNode |
	 existingHierarchyNode := list at: anIndex ifAbsent: [^nil]. 
	^self remove: existingHierarchyNode.

	"Modified: 10.10.94 / 16:13:36 / W.Olberding"!

root: aHierarchyNode
	"Set the root object - this means initialization."

	root :=  aHierarchyNode.
	self initialize.

	"Modified: 10.10.94 / 16:13:36 / W.Olberding"!

selectedPath 
	"Answer the pathName to the currently selected node."

	 | selectedNode |
	selection isNil ifTrue: [^String new].
	selectedNode := list at: selection ifAbsent: [^String new].   
	^selectedNode pathName.

	"Modified: 10.10.94 / 16:13:36 / W.Olberding"!

setHideToChildren: aBoolean startingAt: aHierarchyNode

     "set the hide-Falg to aBoolean starting at aHierarchyNode down"

     |allNodes|

     allNodes:= root allChildren.
     allNodes do: [:each|
	  each hide: aBoolean
     ].
     self setNewList.

	"Modified: 10.10.94 / 16:13:36 / W.Olberding"!

showCompleteHierarchyStartingAtNode: aHierarchyNode
	"Set the hide-Flag to false for the hierarchy starting at aHierarchyNode"

	 | |
	aHierarchyNode isNil ifTrue: [^self].
	aHierarchyNode hideToFalseForPath.
	self setNewList.

	"Modified: 10.10.94 / 16:13:36 / W.Olberding"! !

!SelectionInHierarchy methodsFor:'hierarchy manipulation'!

collapse 
	"If possible, collapse the tree  at the currently selected node.
	 The tree structure can be restored again with #expand. "

	 | selectedNode |
	selectedNode := list at: selection.   
	selectedNode isCollapsable ifTrue: [  selectedNode collapse.
					      ^self setNewList. ].

	"Modified: 10.10.94 / 16:13:37 / W.Olberding"!

collapseAll 
	"If possible, collapse the tree at the currently selected node.
	 A latter #expand will show the next hierarchy level"

	 | selectedNode |
	selectedNode := list at: selection.   
	selectedNode isCollapsable ifTrue: [  selectedNode collapseAll.
					      ^self setNewList. ].

	"Modified: 10.10.94 / 16:13:37 / W.Olberding"!

expand 
	"If possible, expand  the tree 
	 at the currently selected node."

	 | selectedNode |
	selectedNode := list at: selection.
	selectedNode isExpandable  ifTrue: [ selectedNode expand.
					     ^self setNewList. ].

	"Modified: 10.10.94 / 16:13:37 / W.Olberding"!

expandAll 
	"If possible, expand  the tree compleately to all leaves
	 at the currently selected node."

	 | selectedNode |
	selectedNode := list at: selection.
	selectedNode expandAll.
       ^self setNewList.

	"Modified: 10.10.94 / 16:13:37 / W.Olberding"!

hideShow
	"If possible, expand or collaps the tree 
	 at the currently selected node."

	 | selectedNode |
	selectedNode := list at: selection.
	selectedNode isExpandable  ifTrue: [ selectedNode expand.
					     ^self setNewList. ].
	selectedNode isCollapsable ifTrue: [ selectedNode collapse.
					      ^self setNewList. ].

	"Modified: 10.10.94 / 16:13:37 / W.Olberding"! !

!SelectionInHierarchy methodsFor:'initialization'!

initialize

       " nodes := Set new. ***"
	selection := nil.
	self setNewList.

	"Modified: 10.10.94 / 16:13:37 / W.Olberding"! !

!SelectionInHierarchy methodsFor:'private'!

setNewList
	"Travers the tree and build a new list."

	list :=  root withAllShownChildren.
	self changed: #list.

	"Modified: 10.10.94 / 16:13:37 / W.Olberding"! !

!SelectionInHierarchy methodsFor:'selection'!

doubleClickSelection: anIndex
        "Set the current selected object to be the element
        at anIndex of the selection list.
        Also expand or collapse the tree at that point."

        self selectionIndex:  anIndex.  
        self hideShow.

    "Modified: 10.10.1994 / 16:13:36 / W.Olberding"
    "Modified: 11.10.1996 / 15:19:35 / cg"
!

selection
        "Answer the current selection as
          anIndex of the selection list."

        ^ self selectionIndex

    "Modified: 10.10.1994 / 16:13:36 / W.Olberding"
    "Modified: 11.10.1996 / 15:21:30 / cg"
!

selection: anIndex
        "Set the current selected object to be the element
        at anIndex of the selection list."

     ^ self selectionIndex:anIndex

    "Modified: 11.10.1996 / 15:21:15 / cg"
!

selectionIndex
        "Answer the current selection as
          anIndex of the selection list."

    ^ selection

    "Modified: 10.10.1994 / 16:13:36 / W.Olberding"
    "Created: 11.10.1996 / 15:18:44 / cg"
    "Modified: 11.10.1996 / 15:20:46 / cg"
!

selectionIndex: anIndex
        "Set the current selected object to be the element
        at anIndex of the selection list."

        anIndex isNil 
            ifTrue:  [ selection := 0]
            ifFalse: [
                  (selection = anIndex) 
                       ifTrue:  [^nil] 
                       ifFalse: [selection := anIndex ].
            ].
        self changed: #selection.

    "Modified: 10.10.1994 / 16:13:36 / W.Olberding"
    "Created: 11.10.1996 / 15:16:30 / cg"
! !

!SelectionInHierarchy methodsFor:'testing & debugging'!

root

	^root

	"Modified: 10.10.94 / 16:13:37 / W.Olberding"! !

!SelectionInHierarchy  class methodsFor:'documentation'!

version
    ^ '$Header: /cvs/stx/stx/libwidg2/Attic/SelHier.st,v 1.5 1996-10-11 14:46:09 cg Exp $'
! !
